@@ -214,7 +214,7 @@ class Arch:
             (_, _), max_offset = max(_pyvex.vex_ffi.guest_offsets.items(), key=lambda x: x[1])
             max_offset += self.bits
             # Register collections
-            if type(self.vex_arch) is str:
+            if isinstance(self.vex_arch, str):
                 va = self.vex_arch[7:].lower()  # pylint: disable=unsubscriptable-object
                 for r in self.register_list:
                     if r.vex_offset is None:
@@ -363,7 +363,11 @@ class Arch:
         on an ARM platform.
         """
         for r in self.register_list:
-            if reg_name == r.name or reg_name in r.alias_names:
+            if (
+                reg_name == r.name
+                or reg_name in r.alias_names
+                or reg_name in [sub_reg[0] for sub_reg in r.subregisters]
+            ):
                 return r
         return None
 
